/****************************************************************************
*  This file is part of the WLAN-Ethernut device driver.
*
*  Copyright (c) 2004 by Michael Fischer. All rights reserved.
*
*  Redistribution and use in source and binary forms, with or without 
*  modification, are permitted provided that the following conditions 
*  are met:
*  
*  1. Redistributions of source code must retain the above copyright 
*     notice, this list of conditions and the following disclaimer.
*  2. Redistributions in binary form must reproduce the above copyright
*     notice, this list of conditions and the following disclaimer in the 
*     documentation and/or other materials provided with the distribution.
*  3. Neither the name of the author nor the names of its contributors may 
*     be used to endorse or promote products derived from this software 
*     without specific prior written permission.
*
*  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS 
*  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
*  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS 
*  FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL 
*  THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, 
*  INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, 
*  BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS 
*  OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED 
*  AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, 
*  OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF 
*  THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF 
*  SUCH DAMAGE.
*
****************************************************************************
*  History:
*
*  07.02.04  mifi   First Version for the XC9572-PC84 ONLY!
****************************************************************************/
#ifndef __PCMCIA_H__
#define __PCMCIA_H__

#include <iom128v.h>
#include <macros.h>
#include "typedefs.h"

/*-------------------------------------------------------------------------*/
/* global defines                                                          */
/*-------------------------------------------------------------------------*/
/*
 * Base address
*/
#define MEM_BASE_ADDRESS  0xD000
#define IO_BASE_ADDRESS   0xD400
#define RD_LO_BYTE        0xD570
#define RD_HI_BYTE        0xD571
#define WR_HI_BYTE        0xD571
#define CTRL_REG          0xD572

/*
 * CTRL bit definition
*/
#define CTRL_READY        0x01


#define ReadLoByte  *((volatile BYTE *)RD_LO_BYTE)
#define ReadHiByte  *((volatile BYTE *)RD_HI_BYTE)
#define WriteHiByte *((volatile BYTE *)WR_HI_BYTE)
#define CtrlReg     *((volatile BYTE *)CTRL_REG)

/*-------------------------------------------------------------------------*/
/* global types                                                            */
/*-------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------*/
/* global macros                                                           */
/*-------------------------------------------------------------------------*/

/*-------------------------------------------------------------------------*/
/* Prototypes                                                              */
/*-------------------------------------------------------------------------*/
void pcmcia_WriteReg(WORD wAddress, WORD wData);
void pcmcia_WriteMem(WORD wAddress, WORD wData);

WORD pcmcia_ReadReg(WORD wAddress);
WORD pcmcia_ReadMem(WORD wAddress);

void pcmcia_WriteData0(WORD wData);

#endif /* !__PCMCIA_H__ */
